==> ftbucket0.6.30.tar.gz: ftbucket0.6.30/src/phplib/contextmenu.js <==
var search_ascii2d;
$(function(){
  search_ascii2d = function(u,id) {
    var d = document;
    var f = d.createElement('form');
    var fid = 'myform_' + id;
    f.action = 'http://www.ascii2d.net/imagesearch/search';
    f.method = 'post';
    f.name = fid;
    f.id = fid;
    f.target = '_blank';
    var i = d.createElement('input');
    i.type = 'hidden';
    i.name = 'uri';
    i.value = u;
    f.appendChild(i);
    d.body.appendChild(f);
    d.getElementById(fid).submit();
  }
  var re = new RegExp("/img/[^/]+\....$", "i");
  $("a").each(function(idx, elem) {
    if( elem.href.match(re) ){
      //ENbNj[ǉ
      var linkid = "menuid_" + idx;
      var newmenu = $("<menu/>")
                    .attr("id", linkid)
                    .attr("type","context");
      
      newmenu.append(
        $("<menuitem/>")
          .attr("label","񎟌摜ڍ׌")
          .attr("onclick","search_ascii2d('" + elem.href + "'," + idx + ")")
        );

      $("body").append(newmenu);
      elem.setAttribute("contextmenu",linkid);
      
      //Np̖Oǉ
      var tail  = elem.href.replace(/^(.*)\/img\/([^\/]+)$/i,"img/$2");
      var code  = tail.replace("/","_").replace(".","_");
      elem.name = 'lb_' + code;
      elem.id   = 'lb_' + code;
    }
  });

  //[_E[h]{^̕\
  function basename(path) {
    return path.replace(/\\/g,'/').replace( /.*\//, '' );
  }
  function dirname(path) {
    return path.replace(/\\/g,'/').replace(/\/[^\/]*$/, '');;
  }
  var dirbase = basename(dirname(location.href));
  var baseurl = "http://"+ dirbase.replace(/_/gi,"/") + ".htm";

  //[_E[h]{^̕\
  $("span").each(function(idx,elem){
    if(idx == 0){
      $("<span>[<a href='../../download.php?rooturl="+encodeURIComponent(baseurl)+"'>DL</a>]</span>").insertAfter(this);
    }
  });

  $("body small:last").replaceWith($(
    "<span>[<a href='../../'>gbvy[W֖߂</a>] "+
    "[<a href='../../download.php?rooturl="+encodeURIComponent(baseurl)+"'>DL</a>]</span>"
    ));
  
  //X}zANZX̉摜X₷
  var _ua = (function(u){
    return {
      Tablet:(u.indexOf("windows") != -1 && u.indexOf("touch") != -1 && u.indexOf("tablet pc") == -1) 
        || u.indexOf("ipad") != -1
        || (u.indexOf("android") != -1 && u.indexOf("mobile") == -1)
        || (u.indexOf("firefox") != -1 && u.indexOf("tablet") != -1)
        || u.indexOf("kindle") != -1
        || u.indexOf("silk") != -1
        || u.indexOf("playbook") != -1,
      Mobile:(u.indexOf("windows") != -1 && u.indexOf("phone") != -1)
        || u.indexOf("iphone") != -1
        || u.indexOf("ipod") != -1
        || (u.indexOf("android") != -1 && u.indexOf("mobile") != -1)
        || (u.indexOf("firefox") != -1 && u.indexOf("mobile") != -1)
        || u.indexOf("blackberry") != -1
    }
  })(window.navigator.userAgent.toLowerCase());

  if(_ua.Mobile || _ua.Tablet){
    $("blockquote").before("<div style='clear: both;'>");
    $("blockquote").css("margin-left","20px");
  }

});

==> ftbucket0.6.35.tar.gz: ftbucket0.6.35/src/phplib/contextmenu.js <==
var search_ascii2d;
$(function(){
  search_ascii2d = function(u,id) {
    var d = document;
    var f = d.createElement('form');
    var fid = 'myform_' + id;
    f.action = 'http://www.ascii2d.net/imagesearch/search';
    f.method = 'post';
    f.name = fid;
    f.id = fid;
    f.target = '_blank';
    var i = d.createElement('input');
    i.type = 'hidden';
    i.name = 'uri';
    i.value = u;
    f.appendChild(i);
    d.body.appendChild(f);
    d.getElementById(fid).submit();
  }
  var re = new RegExp("/img/[^/]+\....$", "i");
  $("a").each(function(idx, elem) {
    if( elem.href.match(re) ){
      //ENbNj[ǉ
      var linkid = "menuid_" + idx;
      var newmenu = $("<menu/>")
                    .attr("id", linkid)
                    .attr("type","context");
      
      newmenu.append(
        $("<menuitem/>")
          .attr("label","񎟌摜ڍ׌")
          .attr("onclick","search_ascii2d('" + elem.href + "'," + idx + ")")
        );

      $("body").append(newmenu);
      elem.setAttribute("contextmenu",linkid);
      
      //Np̖Oǉ
      var tail  = elem.href.replace(/^(.*)\/img\/([^\/]+)$/i,"img/$2");
      var code  = tail.replace("/","_").replace(".","_");
      elem.name = 'lb_' + code;
      elem.id   = 'lb_' + code;
    }
  });

  //[_E[h]{^̕\
  function basename(path) {
    return path.replace(/\\/g,'/').replace( /.*\//, '' );
  }
  function dirname(path) {
    return path.replace(/\\/g,'/').replace(/\/[^\/]*$/, '');;
  }
  var dirbase = basename(dirname(location.href));
  var baseurl = "http://"+ dirbase.replace(/_/gi,"/") + ".htm";

  //[_E[h]{^̕\
  $("span:first").replaceWith($(
     "<span>[<a href='../../'>gbvy[W</a>]"+
     "[<a href='../../download.php?rooturl="+encodeURIComponent(baseurl)+"'>DL</a>]</span>"
     ));


  $("body small:last").replaceWith($(
    "<span>[<a href='../../'>gbvy[W</a>] "+
    "[<a href='../../download.php?rooturl="+encodeURIComponent(baseurl)+"'>DL</a>]</span>"
    ));
/*
  $("body small:last").replaceWith($(
        '<div id="boxArea" style="display:table;padding:0 0 0 2px;">'+
        "  <span style='float:left;'>[<a href='../../'>gbvy[W</a>]</span> "+
        "  <span style='float:left;'>[<a href='../../download.php?rooturl="+encodeURIComponent(baseurl)+"'>DL</a>]</span>"+
        ' <div style="width:74px;height:22px;float:left;">'+
        '  <a href="https://twitter.com/share" class="twitter-share-button"{count} data-lang="ja" data-dnt="true">cC[g</a>'+
        ' </div>'+
        ' <div style="width:67px;height:22px;float:left;">'+
        '  <a data-pocket-label="pocket" data-pocket-count="none" class="pocket-btn" data-lang="en"></a>'+
        ' </div>'+
        '</div>'
    ));

  ! function(d, s, id) {
      var js, fjs = d.getElementsByTagName(s)[0],
          p = /^http:/.test(d.location) ? 'http' : 'https';
      if (!d.getElementById(id)) {
          js = d.createElement(s);
          js.id = id;
          js.src = p + '://platform.twitter.com/widgets.js';
          fjs.parentNode.insertBefore(js, fjs);
      }
  }(document, 'script', 'twitter-wjs');
  ! function(d, i) {
      if (!d.getElementById(i)) {
          var j = d.createElement("script");
          j.id = i;
          j.src = "https://widgets.getpocket.com/v1/j/btn.js?v=1";
          var w = d.getElementById(i);
          d.body.appendChild(j);
      }
  }(document, "pocket-btn-js");
//*/
  
  //X}zANZX̉摜X₷
  var _ua = (function(u){
    return {
      Tablet:(u.indexOf("windows") != -1 && u.indexOf("touch") != -1 && u.indexOf("tablet pc") == -1) 
        || u.indexOf("ipad") != -1
        || (u.indexOf("android") != -1 && u.indexOf("mobile") == -1)
        || (u.indexOf("firefox") != -1 && u.indexOf("tablet") != -1)
        || u.indexOf("kindle") != -1
        || u.indexOf("silk") != -1
        || u.indexOf("playbook") != -1,
      Mobile:(u.indexOf("windows") != -1 && u.indexOf("phone") != -1)
        || u.indexOf("iphone") != -1
        || u.indexOf("ipod") != -1
        || (u.indexOf("android") != -1 && u.indexOf("mobile") != -1)
        || (u.indexOf("firefox") != -1 && u.indexOf("mobile") != -1)
        || u.indexOf("blackberry") != -1
    }
  })(window.navigator.userAgent.toLowerCase());

  if(_ua.Mobile || _ua.Tablet){
    $("blockquote").before("<div style='clear: both;'>");
    $("blockquote").css("margin-left","20px");
  }

});
